@@ -295,7 +295,7 @@ class UserRepository(AbstractRepository):
         for d in path.iterdir():
             if not d.is_dir():
                 continue
-            yield cls(base, d.name)
+            yield base.get_user_repo(d.name)
 
     def _parse_disk_usage_file(self) -> int:
         du_path = self.path() / ".disk_usage"
