@@ -127,7 +127,7 @@ class Version(SubDir):
 
     def is_stable(self) -> bool:
         for fmt in self.get_formats():
-            stable_path = fmt.path().resolve().parent / ".stable"
+            stable_path = fmt.path().resolve().parent.parent / ".stable"
             if stable_path.is_file():
                 return True
         return False
