@@ -2,6 +2,8 @@
 # Copyright (c) 2021 Robin Jarry
 # SPDX-License-Identifier: BSD-3-Clause
 
+from typing import Callable
+
 from aiohttp import web
 import aiohttp_jinja2
 
@@ -144,6 +146,7 @@ class ProductBranchView(BaseView):
                         "timestamp": v.timestamp,
                         "locked": v.is_locked(),
                         "released": v.is_released(),
+                        "stable": v.is_stable(),
                     }
                 )
         data = {
@@ -172,7 +175,9 @@ class VersionView(BaseView):
         """
         Get the list of versions for a product version.
         """
-        version = _get_version(self.repo(), self.request.match_info)
+        version = _get_version(
+            self.repo(), self.request.match_info, self.access_granted
+        )
         if version.url() != self.request.path:
             raise web.HTTPFound(version.url())
         html = "html" in self.request.headers.get("Accept", "json")
@@ -224,22 +229,27 @@ class VersionArchiveView(BaseView):
         return digests
 
     async def get(self):
-        version = _get_version(self.repo(), self.request.match_info)
+        version = _get_version(
+            self.repo(), self.request.match_info, self.access_granted
+        )
         url = version.url().rstrip("/") + ".tar"
         if url != self.request.path:
             raise web.HTTPFound(version.url())
         return TarResponse(
-            self._digests(version), version.path(), version.archive_name()
+            self._digests(version),
+            version.path(),
+            version.archive_name(),
+            version.timestamp,
         )
 
 
 # --------------------------------------------------------------------------------------
-def _get_version(repo, match_info):
+def _get_version(repo, match_info, access_cb: Callable[[str], bool] = None):
     version = (
         repo.get_product(match_info["product"])
         .get_variant(match_info["variant"])
         .get_branch(match_info["product_branch"])
-        .get_version(match_info["version"])
+        .get_version(match_info["version"], access_cb)
     )
     if not version.exists():
         raise web.HTTPNotFound()
